// ----------------------------------------------------------------------------
//
//	tabdefs.h
//
// Copyright (C) 2019
//		Dave Freese, W1HKJ
//
// This file is part of fldigi.
//
// Fldigi is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Fldigi is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with fldigi.  If not, see <http://www.gnu.org/licenses/>.
// ----------------------------------------------------------------------------

#ifndef TABDEFS_H
#define TABDEFS_H

#define TAB_OLIVIA			_("Modem/Olivia")
#define TAB_CONTESTIA		_("Modem/Contestia")
#define TAB_DOMINOEX		_("Modem/DominoEX")
#define TAB_RTTY			_("Modem/TTY/Rx")
#define TAB_IFKP			_("Modem/IFKP")
#define TAB_FMT				_("Modem/FMT")
#define TAB_FSQ				_("Modem/FSQ")
#define TAB_MFSK			_("Modem/MFSK")
#define TAB_SCAMP			_("Modem/SCAMP")
#define TAB_THOR			_("Modem/Thor")
#define TAB_PSK				_("Modem/Psk")
#define TAB_MT63			_("Modem/MT-63")
#define TAB_NAVTEX			_("Modem/Navtex")
#define TAB_WEFAX			_("Modem/Wefax")
#define TAB_FELDHELL		_("Modem/Feld Hell")
#define TAB_CW				_("Modem/CW/General")

#define TAB_STATION			_("Operator-Station")

#define TAB_RSID			_("IDs/RsID")

#define TAB_CPU				_("Misc/CPU")
#define TAB_NBEMS			_("Misc/NBEMS")
#define TAB_PSKREPORTER		_("Misc/PSK reporter")
#define TAB_SWEETSPOT		_("Misc/Sweet Spot")
#define TAB_TEXT_CAPTURE	_("Misc/Rx text capture")
#define	TAB_DTMF			_("Misc/DTMF")
#define TAB_MISC_KML		_("Misc/KML")
#define TAB_AUTOSTART		_("Misc/Autostart")
#define TAB_MISC_IO			_("Misc/IO")
#define TAB_MISC_PSM		_("Misc/PSM")

#define TAB_CONTEST_GEN		_("Contests/General")
#define TAB_SOUND_DEVICES	_("Soundcard/Devices")

#define TAB_CONFIG_DIALOG	_("Configure")

#define TAB_UI_GENERAL		_("UI/General")
#define TAB_UI_BROWSER		_("UI/Browser")
#define TAB_UI_MACRO_BTNS	_("UI/Macro buttons")
#define TAB_UI_RXTEXT		_("UI/Rx Text")
#define TAB_UI_TOUCH		_("UI/Touch")

#define TAB_LOGGING			_("Logging")
#define TAB_WEB				_("Web")
#define TAB_CONTESTS		_("Contests")
#define TAB_RIG_CONTROL		_("Rig Control")
#define TAB_RIG_FLRIG		_("Rig Control/flrig")
#define TAB_RIG_RIGCAT		_("Rig Control/CAT (rigcat)")
#define TAB_RIG_HAMLIB		_("Rig Control/Hamlib")

#define TAB_WATERFALL		_("Waterfall")

#define TAB_LOG_N3FJP		_("Logging/N3FJP logs")
#define TAB_LOG_MACLOGGER	_("Logging/MacLogger")
#define TAB_LOG_LOTW		_("Logging/LoTW")

#define TAB_UI_CF_RXTX		_("Colors-Fonts/Rx-Tx")
#define TAB_UI_LOGGING_CLRS	_("Colors-Fonts/Logging controls")
#define TAB_UI_TAB_CLRS		_("Colors-Fonts/Tabs")
#define TAB_UI_FD_CLRS		_("Colors-Fonts/FreqDisp - Meters")
#define TAB_UI_FKEY_CLRS	_("Colors-Fonts/Function keys")

#define TAB_PSKMAIL			_("Web/Pskmail")
#define TAB_MISC_WX			_("Web/WX")

#endif
